@@ -167,7 +167,7 @@ def _inference_single_pose_model(model,
     center, scale = _box2cs(cfg, bbox)
 
     flip_pairs = None
-    if dataset == 'TopDownCocoDataset' or dataset == 'TopDownOCHumanDataset':
+    if dataset in ('TopDownCocoDataset', 'TopDownOCHumanDataset'):
         flip_pairs = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12],
                       [13, 14], [15, 16]]
     elif dataset == 'TopDownCocoWholeBodyDataset':
@@ -191,9 +191,8 @@ def _inference_single_pose_model(model,
         flip_pairs = [[0, 3], [1, 4], [2, 5], [6, 9], [7, 10], [8, 11]]
     elif dataset == 'TopDownMpiiDataset':
         flip_pairs = [[0, 5], [1, 4], [2, 3], [10, 15], [11, 14], [12, 13]]
-    elif (dataset == 'TopDownOneHand10KDataset'
-          or dataset == 'TopDownFreiHandDataset'
-          or dataset == 'TopDownPanopticDataset'):
+    elif dataset in ('OneHand10KDataset', 'FreiHandDataset', 'PanopticDataset',
+                     'InterHand2DDataset'):
         flip_pairs = []
     else:
         raise NotImplementedError()
@@ -234,10 +233,10 @@ def _inference_single_pose_model(model,
     # forward the model
     with torch.no_grad():
         all_preds, _, _, heatmap = model(
-            return_loss=False,
-            return_heatmap=return_heatmap,
             img=data['img'],
-            img_metas=data['img_metas'])
+            img_metas=data['img_metas'],
+            return_loss=False,
+            return_heatmap=return_heatmap)
     return all_preds[0], heatmap
 
 
@@ -291,9 +290,10 @@ def inference_top_down_pose_model(model,
 
     if len(person_bboxes) > 0:
         if bbox_thr is not None:
+            assert person_bboxes.shape[1] == 5
             person_bboxes = person_bboxes[person_bboxes[:, 4] > bbox_thr]
 
-        with OutputHook(model, outputs=outputs, as_tensor=True) as h:
+        with OutputHook(model, outputs=outputs, as_tensor=False) as h:
             for bbox in person_bboxes:
                 pose, heatmap = _inference_single_pose_model(
                     model,
@@ -316,7 +316,10 @@ def inference_top_down_pose_model(model,
     return pose_results, returned_outputs
 
 
-def inference_bottom_up_pose_model(model, img_or_path):
+def inference_bottom_up_pose_model(model,
+                                   img_or_path,
+                                   return_heatmap=False,
+                                   outputs=None):
     """Inference a single image.
 
     num_people: P
@@ -327,16 +330,22 @@ def inference_bottom_up_pose_model(model, img_or_path):
     Args:
         model (nn.Module): The loaded pose model.
         image_name (str| np.ndarray): Image_name.
+        return_heatmap (bool) : Flag to return heatmap, default: False
+        outputs (list(str) | tuple(str)) : Names of layers whose outputs
+            need to be returned, default: None
 
     Returns:
         list[ndarray]: The predicted pose info.
-
-            The length of the list
-            is the number of people (P). Each item in the
-            list is a ndarray, containing each person's
-            pose (ndarray[Kx3]): x, y, score
+            The length of the list is the number of people (P).
+            Each item in the list is a ndarray, containing each person's
+            pose (ndarray[Kx3]): x, y, score.
+        list[dict[np.ndarray[N, K, H, W] | torch.tensor[N, K, H, W]]]:
+            Output feature maps from layers specified in `outputs`.
+            Includes 'heatmap' if `return_heatmap` is True.
     """
     pose_results = []
+    returned_outputs = []
+
     cfg = model.cfg
     device = next(model.parameters()).device
 
@@ -367,17 +376,26 @@ def inference_bottom_up_pose_model(model, img_or_path):
         # just get the actual data from DataContainer
         data['img_metas'] = data['img_metas'].data[0]
 
-    # forward the model
-    with torch.no_grad():
-        all_preds, _, _, heatmap = model(
-            return_loss=False, img=data['img'], img_metas=data['img_metas'])
+    with OutputHook(model, outputs=outputs, as_tensor=False) as h:
+        # forward the model
+        with torch.no_grad():
+            all_preds, _, _, heatmap = model(
+                img=data['img'],
+                img_metas=data['img_metas'],
+                return_loss=False,
+                return_heatmap=return_heatmap)
 
-    for pred in all_preds:
-        pose_results.append({
-            'keypoints': pred[:, :3],
-        })
+        if return_heatmap:
+            h.layer_outputs['heatmap'] = heatmap
 
-    return pose_results, heatmap
+        returned_outputs.append(h.layer_outputs)
+
+        for pred in all_preds:
+            pose_results.append({
+                'keypoints': pred[:, :3],
+            })
+
+    return pose_results, returned_outputs
 
 
 def vis_pose_result(model,
@@ -412,8 +430,8 @@ def vis_pose_result(model,
 
     radius = 4
 
-    if dataset == 'TopDownCocoDataset' or dataset == 'BottomUpCocoDataset' \
-            or dataset == 'TopDownOCHumanDataset':
+    if dataset in ('TopDownCocoDataset', 'BottomUpCocoDataset',
+                   'TopDownOCHumanDataset'):
         # show the results
         skeleton = [[16, 14], [14, 12], [17, 15], [15, 13], [12, 13], [6, 12],
                     [7, 13], [6, 7], [6, 8], [7, 9], [8, 10], [9, 11], [2, 3],
@@ -481,9 +499,8 @@ def vis_pose_result(model,
             16, 16, 16, 16, 16, 16, 7, 7, 0, 0, 9, 9, 9, 9, 9, 9
         ]]
 
-    elif (dataset == 'TopDownOneHand10KDataset'
-          or dataset == 'TopDownFreiHandDataset'
-          or dataset == 'TopDownPanopticDataset'):
+    elif dataset in ('OneHand10KDataset', 'FreiHandDataset',
+                     'PanopticDataset'):
         skeleton = [[1, 2], [2, 3], [3, 4], [4, 5], [1, 6], [6, 7], [7, 8],
                     [8, 9], [1, 10], [10, 11], [11, 12], [12, 13], [1, 14],
                     [14, 15], [15, 16], [16, 17], [1, 18], [18, 19], [19, 20],
@@ -497,6 +514,20 @@ def vis_pose_result(model,
             16
         ]]
 
+    elif dataset == 'InterHand2DDataset':
+        skeleton = [[1, 2], [2, 3], [3, 4], [5, 6], [6, 7], [7, 8], [9, 10],
+                    [10, 11], [11, 12], [13, 14], [14, 15], [15, 16], [17, 18],
+                    [18, 19], [19, 20], [4, 21], [8, 21], [12, 21], [16, 21],
+                    [20, 21]]
+
+        pose_limb_color = palette[[
+            0, 0, 0, 4, 4, 4, 8, 8, 8, 12, 12, 12, 16, 16, 16, 0, 4, 8, 12, 16
+        ]]
+        pose_kpt_color = palette[[
+            0, 0, 0, 0, 4, 4, 4, 4, 8, 8, 8, 8, 12, 12, 12, 12, 16, 16, 16, 16,
+            0
+        ]]
+
     else:
         raise NotImplementedError()
 
