@@ -49,7 +49,7 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
         self.use_gt_bbox = data_cfg['use_gt_bbox']
         self.bbox_file = data_cfg['bbox_file']
         self.image_thr = data_cfg['image_thr']
-
+        self.use_nms = data_cfg.get('use_nms', True)
         self.soft_nms = data_cfg['soft_nms']
         self.nms_thr = data_cfg['nms_thr']
         self.oks_thr = data_cfg['oks_thr']
@@ -125,7 +125,8 @@ class TopDownCocoWholeBodyDataset(TopDownCocoDataset):
         print(f'=> num_images: {self.num_images}')
         print(f'=> load {len(self.db)} samples')
 
-    def _make_flip_pairs(self):
+    @staticmethod
+    def _make_flip_pairs():
         body = [[1, 2], [3, 4], [5, 6], [7, 8], [9, 10], [11, 12], [13, 14],
                 [15, 16]]
         foot = [[17, 20], [18, 21], [19, 22]]
