@@ -76,7 +76,7 @@ def _resize_align_multi_scale(image, input_size, current_scale, min_scale):
     return image_resized, center, scale
 
 
-class HeatmapGenerator():
+class HeatmapGenerator:
     """Generate heatmaps for bottom-up models.
 
     Args:
@@ -126,7 +126,7 @@ class HeatmapGenerator():
         return hms
 
 
-class JointsEncoder():
+class JointsEncoder:
     """Encodes the visible joints into (coordinates, score); The coordinate of
     one joint and its score are of `int` type.
 
@@ -165,8 +165,8 @@ class JointsEncoder():
             tot = 0
             for idx, pt in enumerate(joints[i]):
                 x, y = int(pt[0]), int(pt[1])
-                if (pt[2] > 0 and x >= 0 and y >= 0 and x < self.output_res
-                        and y < self.output_res):
+                if (pt[2] > 0 and 0 <= y < self.output_res
+                        and 0 <= x < self.output_res):
                     if self.tag_per_joint:
                         visible_kpts[i][tot] = \
                             (idx * output_res**2 + y * output_res + x, 1)
@@ -229,7 +229,8 @@ class BottomUpRandomAffine:
         self.scale_type = scale_type
         self.trans_factor = trans_factor
 
-    def _get_affine_matrix(self, center, scale, res, rot=0):
+    @staticmethod
+    def _get_affine_matrix(center, scale, res, rot=0):
         """Generate transformation matrix."""
         h = scale
         t = np.zeros((3, 3), dtype=np.float32)
@@ -255,7 +256,8 @@ class BottomUpRandomAffine:
             t = np.dot(t_inv, np.dot(rot_mat, np.dot(t_mat, t)))
         return t
 
-    def _affine_joints(self, joints, mat):
+    @staticmethod
+    def _affine_joints(joints, mat):
         """Affine the joints by the transform matrix."""
         joints = np.array(joints)
         shape = joints.shape
@@ -444,9 +446,9 @@ class BottomUpResizeAlign:
         test_scale_factor = results['ann_info']['test_scale_factor']
         aug_data = []
 
-        for idx, s in enumerate(sorted(test_scale_factor, reverse=True)):
+        for _, s in enumerate(sorted(test_scale_factor, reverse=True)):
             _results = results.copy()
-            image_resized, center, scale = _resize_align_multi_scale(
+            image_resized, _, _ = _resize_align_multi_scale(
                 _results['img'], input_size, s, min(test_scale_factor))
             _results['img'] = image_resized
             _results = self.transforms(_results)
