@@ -4,9 +4,11 @@ from .hourglass import HourglassNet
 from .hrnet import HRNet
 from .mobilenet_v2 import MobileNetV2
 from .mobilenet_v3 import MobileNetV3
+from .mspn import MSPN
 from .regnet import RegNet
 from .resnet import ResNet, ResNetV1d
 from .resnext import ResNeXt
+from .rsn import RSN
 from .scnet import SCNet
 from .seresnet import SEResNet
 from .seresnext import SEResNeXt
@@ -16,5 +18,5 @@ from .shufflenet_v2 import ShuffleNetV2
 __all__ = [
     'AlexNet', 'HourglassNet', 'HRNet', 'MobileNetV2', 'MobileNetV3', 'RegNet',
     'ResNet', 'ResNetV1d', 'ResNeXt', 'SCNet', 'SEResNet', 'SEResNeXt',
-    'ShuffleNetV1', 'ShuffleNetV2', 'CPM'
+    'ShuffleNetV1', 'ShuffleNetV2', 'CPM', 'RSN', 'MSPN'
 ]
