@@ -69,6 +69,7 @@ class BottomUp(BasePose):
                 joints=None,
                 img_metas=None,
                 return_loss=True,
+                return_heatmap=False,
                 **kwargs):
         """Calls either forward_train or forward_test depending on whether
         return_loss is True.
@@ -88,8 +89,6 @@ class BottomUp(BasePose):
                                               heatmaps
             joints(List(torch.Tensor[NxMxKx2])): Joints of multi-scale target
                                                  heatmaps for ae loss
-            return loss(bool): Option to 'return_loss'. 'return_loss=True' for
-                training, 'return_loss=False' for validation & test
             img_metas(dict):Information about val&test
                 By default this includes:
                 - "image_file": image path
@@ -99,17 +98,22 @@ class BottomUp(BasePose):
                 - "center": center of image
                 - "scale": scale of image
                 - "flip_index": flip index of keypoints
+
+            return loss(bool): Option to 'return_loss'. 'return_loss=True' for
+                training, 'return_loss=False' for validation & test
+            return_heatmap (bool) : Option to return heatmap.
+
         Returns:
             dict|tuple: if 'return_loss' is true, then return losses.
-              Otherwise, return predicted poses, scores and image
-              paths.
+              Otherwise, return predicted poses, scores, image
+              paths and heatmaps.
         """
 
         if return_loss:
             return self.forward_train(img, targets, masks, joints, img_metas,
                                       **kwargs)
-        else:
-            return self.forward_test(img, img_metas, **kwargs)
+        return self.forward_test(
+            img, img_metas, return_heatmap=return_heatmap, **kwargs)
 
     def forward_train(self, img, targets, masks, joints, img_metas, **kwargs):
         """Forward the bottom-up model and calculate the loss.
@@ -170,7 +174,23 @@ class BottomUp(BasePose):
         losses['all_loss'] = loss
         return losses
 
-    def forward_test(self, img, img_metas, **kwargs):
+    def forward_dummy(self, img):
+        """Used for computing network FLOPs.
+
+        See ``tools/get_flops.py``.
+
+        Args:
+            img (torch.Tensor): Input image.
+
+        Returns:
+            Tensor: Outputs.
+        """
+        output = self.backbone(img)
+        if self.with_keypoint:
+            output = self.keypoint_head(output)
+        return output
+
+    def forward_test(self, img, img_metas, return_heatmap=False, **kwargs):
         """Inference the bottom-up model.
 
         Note:
@@ -205,12 +225,14 @@ class BottomUp(BasePose):
             image_resized = aug_data[idx].to(img.device)
 
             outputs = self.backbone(image_resized)
-            outputs = self.keypoint_head(outputs)
+            if self.with_keypoint:
+                outputs = self.keypoint_head(outputs)
 
             if self.test_cfg['flip_test']:
                 # use flip test
                 outputs_flip = self.backbone(torch.flip(image_resized, [3]))
-                outputs_flip = self.keypoint_head(outputs_flip)
+                if self.with_keypoint:
+                    outputs_flip = self.keypoint_head(outputs_flip)
             else:
                 outputs_flip = None
 
@@ -243,7 +265,10 @@ class BottomUp(BasePose):
         image_path = []
         image_path.extend(img_metas['image_file'])
 
-        output_heatmap = aggregated_heatmaps.detach().cpu().numpy()
+        if return_heatmap:
+            output_heatmap = aggregated_heatmaps.detach().cpu().numpy()
+        else:
+            output_heatmap = None
 
         return results, scores, image_path, output_heatmap
 
@@ -293,7 +318,7 @@ class BottomUp(BasePose):
         for res in result:
             pose_result.append(res['keypoints'])
 
-        for person_id, kpts in enumerate(pose_result):
+        for _, kpts in enumerate(pose_result):
             # draw each point on image
             if pose_kpt_color is not None:
                 assert len(pose_kpt_color) == len(kpts)
