@@ -105,9 +105,8 @@ class TopDown(BasePose):
         if return_loss:
             return self.forward_train(img, target, target_weight, img_metas,
                                       **kwargs)
-        else:
-            return self.forward_test(
-                img, img_metas, return_heatmap=return_heatmap, **kwargs)
+        return self.forward_test(
+            img, img_metas, return_heatmap=return_heatmap, **kwargs)
 
     def forward_train(self, img, target, target_weight, img_metas, **kwargs):
         """Defines the computation performed at every call when training."""
@@ -157,23 +156,22 @@ class TopDown(BasePose):
         if isinstance(output, list):
             if target.dim() == 5 and target_weight.dim() == 4:
                 _, avg_acc, _ = pose_pck_accuracy(
-                    output[-1][target_weight[:, -1, :, :].squeeze(-1) > 0].
-                    unsqueeze(0).detach().cpu().numpy(),
-                    target[:, -1, :, :, :][target_weight[:, -1, :, :].squeeze(
-                        -1) > 0].unsqueeze(0).detach().cpu().numpy())
+                    output[-1].detach().cpu().numpy(),
+                    target[:, -1, ...].detach().cpu().numpy(),
+                    target_weight[:, -1,
+                                  ...].detach().cpu().numpy().squeeze(-1) > 0)
                 # Only use the last output for prediction
             else:
                 _, avg_acc, _ = pose_pck_accuracy(
-                    output[-1][target_weight.squeeze(-1) > 0].unsqueeze(
-                        0).detach().cpu().numpy(),
-                    target[target_weight.squeeze(-1) > 0].unsqueeze(
-                        0).detach().cpu().numpy())
+                    output[-1].detach().cpu().numpy(),
+                    target.detach().cpu().numpy(),
+                    target_weight.detach().cpu().numpy().squeeze(-1) > 0)
         else:
             _, avg_acc, _ = pose_pck_accuracy(
-                output[target_weight.squeeze(-1) > 0].unsqueeze(
-                    0).detach().cpu().numpy(),
-                target[target_weight.squeeze(-1) > 0].unsqueeze(
-                    0).detach().cpu().numpy())
+                output.detach().cpu().numpy(),
+                target.detach().cpu().numpy(),
+                target_weight.detach().cpu().numpy().squeeze(-1) > 0)
+
         losses['acc_pose'] = float(avg_acc)
 
         return losses
@@ -193,6 +191,22 @@ class TopDown(BasePose):
 
         return all_preds, all_boxes, image_path, heatmap
 
+    def forward_dummy(self, img):
+        """Used for computing network FLOPs.
+
+        See ``tools/get_flops.py``.
+
+        Args:
+            img (torch.Tensor): Input image.
+
+        Returns:
+            Tensor: Output heatmaps.
+        """
+        output = self.backbone(img)
+        if self.with_keypoint:
+            output = self.keypoint_head(output)
+        return output
+
     def process_head(self, output, img, img_metas, return_heatmap=False):
         """Process heatmap and keypoints from backbone features."""
         flip_pairs = img_metas['flip_pairs']
@@ -232,7 +246,7 @@ class TopDown(BasePose):
             c,
             s,
             post_process=self.test_cfg['post_process'],
-            unbiased=self.test_cfg['unbiased_decoding'],
+            unbiased=self.test_cfg.get('unbiased_decoding', False),
             kernel=self.test_cfg['modulate_kernel'])
 
         all_preds = np.zeros((1, output_heatmap.shape[1], 3), dtype=np.float32)
@@ -318,7 +332,7 @@ class TopDown(BasePose):
                 wait_time=wait_time,
                 out_file=None)
 
-            for person_id, kpts in enumerate(pose_result):
+            for _, kpts in enumerate(pose_result):
                 # draw each point on image
                 if pose_kpt_color is not None:
                     assert len(pose_kpt_color) == len(kpts)
